
#ifndef __PFREGEX_H
#define __PFREGEX_H

#define REGEXP_LEN	200

#define SM_FROM		1
#define SM_TO		2
#define SM_SUBJ		4
#define SM_ALL		7

#endif // __PFREGEX_H
